@@ -67,8 +67,8 @@ QPGlobal <- function(local.surfaces , unstable.eq.x , unstable.eq.y , x.bound ,
 		}
 	}
 
-	max.phi <- max(unstable.phi,na.rm=T)
-	max.phi.arr <- which(unstable.phi == max.phi , arr.ind=T)
+	max.phi <- max(unstable.phi, na.rm = TRUE)
+	max.phi.arr <- which(unstable.phi == max.phi , arr.ind = T)
 
 	if(nrow(max.phi.arr) != n.unstable.pts){ #if not all max(phi) are the same, then they need to be aligned
 		global.max <- unstable.phi[max.phi.arr[1,1],max.phi.arr[1,2]]
@@ -87,8 +87,8 @@ QPGlobal <- function(local.surfaces , unstable.eq.x , unstable.eq.y , x.bound ,
 	}
 	rm(eq.arr.unadj)
 	gc()
-	global.qp <- apply(eq.arr , c(1:n.surfaces) , min)
+	global.qp <- apply(eq.arr , c(1, 2) , min)
 	rm(eq.arr)
 	gc()
 	global.qp
-	}
\ No newline at end of file
+	}
